Index: src/mips64/code-stubs-mips64.cc |
diff --git a/src/mips64/code-stubs-mips64.cc b/src/mips64/code-stubs-mips64.cc |
index 2171220846450e45ffd0ca2f15c2d062e2a21f49..adf1af27dc1e616b4c2d11948ac808fea4d313e1 100644 |
--- a/src/mips64/code-stubs-mips64.cc |
+++ b/src/mips64/code-stubs-mips64.cc |
@@ -1417,7 +1417,7 @@ void RegExpExecStub::Generate(MacroAssembler* masm) { |
// (6) External string. Make it, offset-wise, look like a sequential string. |
// Go to (4). |
// (7) Short external string or not a string? If yes, bail out to runtime. |
// (8) Sliced string. Replace subject with parent. Go to (1). |
Label check_underlying; // (1) |
Label seq_string; // (4) |
@@ -1467,8 +1467,8 @@ void RegExpExecStub::Generate(MacroAssembler* masm) { |
__ Branch(&runtime, ls, a3, Operand(a1)); |
__ SmiUntag(a1); |
- STATIC_ASSERT(kStringEncodingMask == 4); |
- STATIC_ASSERT(kOneByteStringTag == 4); |
+ STATIC_ASSERT(kStringEncodingMask == 8); |
+ STATIC_ASSERT(kOneByteStringTag == 8); |
STATIC_ASSERT(kTwoByteStringTag == 0); |
__ And(a0, a0, Operand(kStringEncodingMask)); // Non-zero for one_byte. |
__ ld(t9, FieldMemOperand(regexp_data, JSRegExp::kDataOneByteCodeOffset)); |
@@ -1718,12 +1718,18 @@ void RegExpExecStub::Generate(MacroAssembler* masm) { |
__ And(at, a1, Operand(kIsNotStringMask | kShortExternalStringMask)); |
__ Branch(&runtime, ne, at, Operand(zero_reg)); |
- // (8) Sliced string. Replace subject with parent. Go to (4). |
+ // (8) Sliced or thin string. Replace subject with parent. Go to (4). |
+ Label thin_string; |
+ __ Branch(&thin_string, eq, a1, Operand(kThinStringTag)); |
// Load offset into t0 and replace subject string with parent. |
__ ld(t0, FieldMemOperand(subject, SlicedString::kOffsetOffset)); |
__ SmiUntag(t0); |
__ ld(subject, FieldMemOperand(subject, SlicedString::kParentOffset)); |
__ jmp(&check_underlying); // Go to (1). |
+ |
+ __ bind(&thin_string); |
+ __ ld(subject, FieldMemOperand(subject, ThinString::kActualOffset)); |
+ __ jmp(&check_underlying); // Go to (1). |
#endif // V8_INTERPRETED_REGEXP |
} |
@@ -1417,7 +1417,7 @@ void RegExpExecStub::Generate(MacroAssembler* masm) { |
// Go to (4). |
// (7) Short external string or not a string? If yes, bail out to runtime. |
- // (8) Sliced string. Replace subject with parent. Go to (1). |
+ // (8) Sliced or thin string. Replace subject with parent. Go to (1). |
Label check_underlying; // (1) |
Label seq_string; // (4) |